@@ -14,6 +14,10 @@
 // with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 use super::errors::{DomainChangerError, DomainChangerResult};
+#[cfg(feature = "json")]
+use super::ToFromJson;
+#[cfg(feature = "json")]
+use serde::{Deserialize, Serialize};
 use url::Url;
 
 /// [`Domain`] struct help you to put [`old`] and [`new`] domain
@@ -22,7 +26,8 @@ use url::Url;
 ///
 /// [`new`]: Domain#structfield.new
 /// [`old`]: Domain#structfield.old
-#[derive(Debug, Clone)]
+#[cfg_attr(feature = "json", derive(Serialize, Deserialize))]
+#[derive(Debug, Clone, Eq, PartialEq)]
 pub struct Domain {
     /// old domain to change it
     pub old: Url,
@@ -91,6 +96,22 @@ impl Domain {
     }
 }
 
+/// Implementation [`ToFromJson`] to [`Domain`]
+///
+/// # Example
+/// ```rust
+/// use domain_changer::types::{Domain, ToFromJson};
+///
+/// let domain: Domain = Domain::try_from(("https://twitter.com/", "https://nitter.net/")).unwrap();
+/// assert_eq!(domain.to_json().unwrap(), "{\"old\":\"https://twitter.com/\",\"new\":\"https://nitter.net/\"}");
+/// assert_eq!(Domain::from_json("{\"old\":\"https://twitter.com/\",\"new\":\"https://nitter.net/\"}").unwrap(), domain);
+/// assert!(Domain::from_json("{\"old\":\"twitter.com/\",\"new\":\"nitter.net/\"}").is_err())
+///
+///
+/// ```
+#[cfg(feature = "json")]
+impl ToFromJson<'_> for Domain {}
+
 impl TryFrom<(&str, &str)> for Domain {
     type Error = DomainChangerError;
 
@@ -126,12 +147,6 @@ impl TryFrom<(&str, &str)> for Domain {
     }
 }
 
-impl PartialEq for Domain {
-    fn eq(&self, other: &Self) -> bool {
-        self.old == other.old && self.new == other.new
-    }
-}
-
 #[cfg(test)]
 mod tests {
     use crate::types::{errors::DomainChangerResult, Domain};
